summaryrefslogtreecommitdiffstats
path: root/src/gui/ConnectWindow.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2011-04-20 16:26:40 +0000
committerDavid Robillard <d@drobilla.net>2011-04-20 16:26:40 +0000
commit138a87e915ad3aff184730415105f94c874174bf (patch)
tree0d942bdddfdbcc3d969b4fce5592e770ab851b86 /src/gui/ConnectWindow.cpp
parent1f1758f4dda0ddaf01c0b1d3a756f9db8ddc979d (diff)
downloadingen-138a87e915ad3aff184730415105f94c874174bf.tar.gz
ingen-138a87e915ad3aff184730415105f94c874174bf.tar.bz2
ingen-138a87e915ad3aff184730415105f94c874174bf.zip
Rename Ingen::Engine to Ingen::Server (hopefully avoid odd name clases and fix #675).
git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@3184 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/gui/ConnectWindow.cpp')
-rw-r--r--src/gui/ConnectWindow.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/gui/ConnectWindow.cpp b/src/gui/ConnectWindow.cpp
index f93ebf4c..171113fb 100644
--- a/src/gui/ConnectWindow.cpp
+++ b/src/gui/ConnectWindow.cpp
@@ -25,10 +25,10 @@
#include "raul/log.hpp"
#include "ingen-config.h"
-#include "ingen/EngineInterface.hpp"
+#include "ingen/ServerInterface.hpp"
#include "shared/Module.hpp"
#include "shared/World.hpp"
-#include "engine/Engine.hpp"
+#include "server/Engine.hpp"
#ifdef HAVE_SOUP
#include "client/HTTPClientReceiver.hpp"
#include "client/HTTPEngineSender.hpp"
@@ -83,7 +83,7 @@ ConnectWindow::start(Ingen::Shared::World* world)
}
void
-ConnectWindow::set_connected_to(SharedPtr<EngineInterface> engine)
+ConnectWindow::set_connected_to(SharedPtr<ServerInterface> engine)
{
App::instance().world()->set_engine(engine);
@@ -142,7 +142,7 @@ ConnectWindow::set_connecting_widget_states()
/** Launch (if applicable) and connect to the Engine.
*
* This will create the EngineInterface and ClientInterface and initialize
* the App with them.
*/
void
@@ -193,14 +193,14 @@ ConnectWindow::connect(bool existing)
#ifdef HAVE_LIBLO
if (scheme == "osc.udp" || scheme == "osc.tcp")
world->set_engine(
- SharedPtr<EngineInterface>(
+ SharedPtr<ServerInterface>(
new OSCEngineSender(
uri,
world->conf()->option("packet-size").get_int32())));
#endif
#ifdef HAVE_SOUP
if (scheme == "http")
- world->set_engine(SharedPtr<EngineInterface>(
+ world->set_engine(SharedPtr<ServerInterface>(
new HTTPEngineSender(world, uri)));
#endif
} else {
@@ -222,7 +222,7 @@ ConnectWindow::connect(bool existing)
const string cmd = string("ingen -e --engine-port=").append(port_str);
if (Raul::Process::launch(cmd)) {
- world->set_engine(SharedPtr<EngineInterface>(
+ world->set_engine(SharedPtr<ServerInterface>(
new OSCEngineSender(
string("osc.udp://localhost:").append(port_str),
world->conf()->option("packet-size").get_int32())));
@@ -252,7 +252,7 @@ ConnectWindow::connect(bool existing)
SharedPtr<SigClientInterface> client(new SigClientInterface());
- if (!((Engine::Engine*)world->local_engine().get())->driver())
+ if (!((Server::Engine*)world->local_engine().get())->driver())
world->load_module("jack");
world->local_engine()->activate();
@@ -272,7 +272,7 @@ ConnectWindow::disconnect()
_attached = false;
App::instance().detach();
- set_connected_to(SharedPtr<Ingen::EngineInterface>());
+ set_connected_to(SharedPtr<Ingen::ServerInterface>());
if (!_widgets_loaded)
return;
@@ -142,7 +142,7 @@ ConnectWindow::set_connecting_widget_states()
/** Launch (if applicable) and connect to the Engine.
*
- * This will create the EngineInterface and ClientInterface and initialize
+ * This will create the ServerInterface and ClientInterface and initialize
* the App with them.
*/